View source: R/visualization.R
| aelab_palettes | R Documentation |
Retrieve a named aelab colour palette as a character vector.
aelab_palettes(name, n, type = c("discrete", "continuous"))
name |
Name of the palette (string). |
n |
Number of colours to return. Defaults to the full palette length. |
type |
|
Available palette names: "rainbow", "two",
"control", "control2", "control3",
"period", "ghg".
A character vector of hex colour codes with class "palette".
aelab_palettes("rainbow", 5)
aelab_palettes("ghg", type = "continuous", n = 20)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.