| calc_chla_trichromatic | R Documentation |
Calculate chlorophyll-a concentration from trichromatic spectrophotometric absorbance readings using the Jeffrey & Humphrey (1975) equations.
calc_chla_trichromatic(wl_630, wl_647, wl_664, wl_750)
wl_630 |
Absorbance at 630 nm. |
wl_647 |
Absorbance at 647 nm. |
wl_664 |
Absorbance at 664 nm. |
wl_750 |
Absorbance at 750 nm (turbidity blank). |
Absorbance values should be measured in a 1 cm path-length cuvette.
The 750 nm reading is used as a turbidity blank correction.
Formula: 11.85 \times E_{664} - 1.54 \times E_{647} - 0.08 \times E_{630}
where E_{\lambda} = A_{\lambda} - A_{750}.
Chlorophyll-a concentration in µg L^{-1} (assuming a 1 cm path
length and standard extraction volume).
calc_chla_trichromatic(wl_630 = 0.05, wl_647 = 0.08, wl_664 = 0.20, wl_750 = 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.