Learn R Programming

aelab (version 1.1.0)

calculate_do: calculate_do

Description

Calculate the Net Ecosystem Production, Gross Primary Production and Ecosystem respiration based on the change in dissolved oxygen concentration.

Usage

calculate_do(df)

Value

A dataframe.

Arguments

df

Merged dataframe produced by process_hobo(), process_weather() and process_info() functions.

Examples

Run this code
data(hobo)
calculate_do(hobo)

Run the code above in your browser using DataLab