powered by
Calculate the slope of greenhouse gas (GHG) concentration change over time using simple linear regression.
calculate_regression( data, ghg, reference_time, duration_minutes = 7, num_rows = 300 )
A tibble containing the time range (POSIXct format) of the slope and R2 (both numeric) from the simple linear regression.
Data from the LI-COR Trace Gas Analyzer that has been processed and time-converted.
Column name of the file containing data on GHG concentration (e.g., "CH4", "N2O").
The date and time at which the measurement started.
The duration of the measurement, default to 7.
The number of rows used to perform the regression, default to 300.
data(n2o) calculate_regression(n2o, "N2O", as.POSIXct("2023-05-04 09:16:15", tz = "UTC"))
Run the code above in your browser using DataLab