| convert_time | R Documentation |
Convert the time of the LI-COR Trace Gas Analyzer to match the time in real life.
convert_time(data, day = 0, hr = 0, min = 0, sec = 0)
data |
Data from the LI-COR Trace Gas Analyzer that had been processed by tidy_licor(). |
day |
Day(s) to add or subtract. |
hr |
Hour(s) to add or subtract. |
min |
Minute(s) to add or subtract. |
sec |
Second(s) to add or subtract. |
The input data with a new column in POSIXct format converted based on the input value.
data(n2o)
converted_n2o <- convert_time(n2o, min = -10, sec = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.