powered by
Retrieve a named aelab colour palette as a character vector.
aelab_palettes(name, n, type = c("discrete", "continuous"))
A character vector of hex colour codes with class "palette".
"palette"
Name of the palette (string).
Number of colours to return. Defaults to the full palette length.
"discrete" (default) or "continuous". For "continuous", colours are interpolated to length n.
"discrete"
"continuous"
n
Available palette names: "rainbow", "two", "control", "control2", "control3", "period", "ghg".
"rainbow"
"two"
"control"
"control2"
"control3"
"period"
"ghg"
aelab_palettes("rainbow", 5) aelab_palettes("ghg", type = "continuous", n = 20)
Run the code above in your browser using DataLab