powered by
Calculate the Net Ecosystem Production, Gross Primary Production and Ecosystem respiration based on the change in dissolved oxygen concentration.
calculate_do(df)
A dataframe.
Merged dataframe produced by process_hobo(), process_weather() and process_info() functions.
data(hobo) calculate_do(hobo)
Run the code above in your browser using DataLab