| convert_ghg_unit | R Documentation |
Convert a greenhouse gas (GHG) flux value (or a character string
containing one or more numeric values, e.g. "0.002 +/- 0.003")
to micrograms per square meter per hour.
convert_ghg_unit(
input,
ghg,
mass = "µg",
area = "m2",
time = "hr",
digits = 2,
ratio = FALSE
)
input |
A single numeric value or a character string containing one or more numbers. |
ghg |
The molecular formula of the greenhouse gas: |
mass |
Mass unit of the input flux. One of |
area |
Area unit of the input flux. One of |
time |
Time unit of the input flux. One of |
digits |
Number of decimal places to round to. Default 2. |
ratio |
Logical. If |
Numeric values embedded in a string (e.g. mean +/- SD notation) are each converted individually and the surrounding text is preserved. Commas are treated as decimal separators.
A named list with value (converted string) and unit,
or "EMPTY" for missing/non-numeric input.
convert_ghg_unit(97, ghg = "ch4", mass = "mg", area = "m2", time = "hr")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.