| find_outlier | R Documentation |
Identify outliers in a numeric column using the IQR method
(values outside 1.5 \times IQR from Q1/Q3).
find_outlier(df, var, other_var = NULL)
df |
A data frame. |
var |
Name of the column to check for outliers (string). |
other_var |
Character vector of additional column names to return
alongside the outlier values, or |
A tibble with columns row_index, outlier_value, and any
requested other_var columns.
df <- data.frame(val = c(1, 2, 2, 3, 100), id = 1:5)
find_outlier(df, "val", "id")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.